@@ -1,7 +1,7 @@
 package Net::Docker;
 use strict;
 use 5.010;
-our $VERSION = '0.002003';
+our $VERSION = '0.002004';
 
 use Moo;
 use JSON;
@@ -11,12 +11,16 @@ use LWP::UserAgent;
 use Carp;
 use AnyEvent;
 use AnyEvent::HTTP;
-use Data::Dumper;
 
-has address => (is => 'ro', default => 'http://127.0.0.1:4243');
+has address => (is => 'ro', default => 'http:var/run/docker.sock/');
 has ua      => (is => 'lazy');
 
 sub _build_ua {
+    my $self = shift;
+    if ( $self->address !~ m!http://! ) {
+        require LWP::Protocol::http::SocketUnixAlt;
+        LWP::Protocol::implementor( http => 'LWP::Protocol::http::SocketUnixAlt' );
+    }
     my $ua = LWP::UserAgent->new;
     return $ua;
 }
@@ -36,9 +40,10 @@ sub _parse {
     if ($res->content_type eq 'application/json') {
         return decode_json($res->decoded_content);
     }
-    my $message = $res->decoded_content;
-    $message =~ s/\r?\n$//;
-    croak $message;
+    elsif ($res->content_type eq 'text/plain') {
+        return eval { decode_json($res->decoded_content) };
+    }
+    $res->dump;
 }
 
 sub _parse_request {
